@@ -21,24 +21,34 @@ var (
 
 	ssoConfigs = map[string]ssoConfig{
 		"cpd": {
-			ssoProviderDomain:     "login-cpd.confluent-dev.io",
+			ssoProviderDomain:     "login-cpd.confluent-dev.io/oauth",
 			ssoProviderIdentifier: "https://confluent-cpd.auth0.com/api/v2/",
+			ssoProviderScope:      "email%20openid%20offline_access",
 		},
 		"devel": {
-			ssoProviderDomain:     "login.confluent-dev.io",
+			ssoProviderDomain:     "login.confluent-dev.io/oauth",
 			ssoProviderIdentifier: "https://confluent-dev.auth0.com/api/v2/",
+			ssoProviderScope:      "email%20openid%20offline_access",
+		},
+		"fedramp-internal": {
+			ssoProviderDomain: "confluent-infra-us-gov.oktapreview.com/oauth2/v1",
+			ssoProviderScope:  "openid+profile+email+offline_access",
+			ssoProviderIDP:    "0oa7fi3wpt9LC2ONd1d7",
 		},
 		"stag": {
-			ssoProviderDomain:     "login-stag.confluent-dev.io",
+			ssoProviderDomain:     "login-stag.confluent-dev.io/oauth",
 			ssoProviderIdentifier: "https://confluent-stag.auth0.com/api/v2/",
+			ssoProviderScope:      "email%20openid%20offline_access",
 		},
 		"prod": {
-			ssoProviderDomain:     "login.confluent.io",
+			ssoProviderDomain:     "login.confluent.io/oauth",
 			ssoProviderIdentifier: "https://confluent.auth0.com/api/v2/",
+			ssoProviderScope:      "email%20openid%20offline_access",
 		},
 		"test": {
-			ssoProviderDomain:     "test.com",
+			ssoProviderDomain:     "test.com/oauth",
 			ssoProviderIdentifier: "https://test.auth0.com/api/v2/",
+			ssoProviderScope:      "email%20openid%20offline_access",
 		},
 	}
 )
@@ -46,6 +56,8 @@ var (
 type ssoConfig struct {
 	ssoProviderDomain     string
 	ssoProviderIdentifier string
+	ssoProviderScope      string
+	ssoProviderIDP        string
 }
 
 /*
@@ -63,6 +75,8 @@ type authState struct {
 	SSOProviderClientID           string
 	SSOProviderCallbackUrl        string
 	SSOProviderIdentifier         string
+	SSOProviderScope              string
+	SSOProviderIDP                string
 }
 
 // InitState generates various auth0 related codes and hashes
@@ -84,6 +98,8 @@ func newState(authURL string, noBrowser bool) (*authState, error) {
 		env = "devel"
 	} else if authURL == "https://stag.cpdev.cloud" {
 		env = "stag"
+	} else if authURL == "https://infra.confluentgov-internal.com" {
+		env = "fedramp-internal"
 	} else if authURL == testserver.TestCloudUrl.String() {
 		env = "test"
 	} else {
@@ -95,6 +111,8 @@ func newState(authURL string, noBrowser bool) (*authState, error) {
 	state.SSOProviderHost = "https://" + ssoConfigs[env].ssoProviderDomain
 	state.SSOProviderClientID = GetAuth0CCloudClientIdFromBaseUrl(authURL)
 	state.SSOProviderIdentifier = ssoConfigs[env].ssoProviderIdentifier
+	state.SSOProviderScope = ssoConfigs[env].ssoProviderScope
+	state.SSOProviderIDP = ssoConfigs[env].ssoProviderIDP
 
 	if !noBrowser {
 		// if we're not using the no browser flow, the callback will always be localhost regardless of environment
@@ -185,7 +203,7 @@ func (s *authState) saveOAuthTokenResponse(data map[string]any) error {
 }
 
 func (s *authState) getOAuthTokenResponse(payload *strings.Reader) (map[string]any, error) {
-	url := s.SSOProviderHost + "/oauth/token"
+	url := s.SSOProviderHost + "/token"
 	log.CliLogger.Debugf("Oauth token request URL: %s", url)
 	log.CliLogger.Debug("Oauth token request payload: ", payload)
 	req, err := http.NewRequest(http.MethodPost, url, payload)
@@ -215,11 +233,15 @@ func (s *authState) getAuthorizationCodeUrl(ssoProviderConnectionName string) st
 		"&code_challenge_method=S256" +
 		"&client_id=" + s.SSOProviderClientID +
 		"&redirect_uri=" + s.SSOProviderCallbackUrl +
-		"&scope=email%20openid%20offline_access" +
-		"&audience=" + s.SSOProviderIdentifier +
+		"&scope=" + s.SSOProviderScope +
 		"&state=" + s.SSOProviderState
+
+	if s.SSOProviderIdentifier != "" {
+		url += "&audience=" + s.SSOProviderIdentifier
+	}
 	if ssoProviderConnectionName != "" {
 		url += "&connection=" + ssoProviderConnectionName
 	}
+
 	return url
 }
